""" Code is generated by ucloud-model, DO NOT EDIT IT. """


from ucloud.core.typesystem import schema, fields
from ucloud.services.ulb.schemas import models

""" ULB API Schema
"""


"""
API: AllocateBackend

添加ULB后端资源实例
"""


class AllocateBackendRequestSchema(schema.RequestSchema):
    """AllocateBackend - 添加ULB后端资源实例"""

    fields = {
        "Enabled": fields.Int(required=False, dump_to="Enabled"),
        "IsBackup": fields.Int(required=False, dump_to="IsBackup"),
        "Port": fields.Int(required=False, dump_to="Port"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "ResourceIP": fields.Str(required=False, dump_to="ResourceIP"),
        "ResourceId": fields.Str(required=True, dump_to="ResourceId"),
        "ResourceType": fields.Str(required=True, dump_to="ResourceType"),
        "SubnetId": fields.Str(required=False, dump_to="SubnetId"),
        "ULBId": fields.Str(required=True, dump_to="ULBId"),
        "VPCId": fields.Str(required=False, dump_to="VPCId"),
        "VServerId": fields.Str(required=True, dump_to="VServerId"),
        "Weight": fields.Int(required=False, dump_to="Weight"),
    }


class AllocateBackendResponseSchema(schema.ResponseSchema):
    """AllocateBackend - 添加ULB后端资源实例"""

    fields = {
        "BackendId": fields.Str(required=False, load_from="BackendId"),
    }


"""
API: AllocateBackendBatch


"""


class AllocateBackendBatchRequestSchema(schema.RequestSchema):
    """AllocateBackendBatch -"""

    fields = {
        "ApiVersion": fields.Int(required=False, dump_to="ApiVersion"),
        "Backends": fields.List(fields.Str()),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "ULBId": fields.Str(required=True, dump_to="ULBId"),
        "VServerId": fields.Str(required=True, dump_to="VServerId"),
    }


class AllocateBackendBatchResponseSchema(schema.ResponseSchema):
    """AllocateBackendBatch -"""

    fields = {
        "BackendSet": fields.List(
            models.BackendSetSchema(), required=False, load_from="BackendSet"
        ),
    }


"""
API: BindSSL

将SSL证书绑定到VServer
"""


class BindSSLRequestSchema(schema.RequestSchema):
    """BindSSL - 将SSL证书绑定到VServer"""

    fields = {
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SSLId": fields.Str(required=True, dump_to="SSLId"),
        "ULBId": fields.Str(required=True, dump_to="ULBId"),
        "VServerId": fields.Str(required=True, dump_to="VServerId"),
    }


class BindSSLResponseSchema(schema.ResponseSchema):
    """BindSSL - 将SSL证书绑定到VServer"""

    fields = {}


"""
API: CreatePolicy

创建VServer内容转发策略
"""


class CreatePolicyRequestSchema(schema.RequestSchema):
    """CreatePolicy - 创建VServer内容转发策略"""

    fields = {
        "BackendId": fields.List(fields.Str()),
        "Match": fields.Str(required=True, dump_to="Match"),
        "PolicyPriority": fields.Int(required=False, dump_to="PolicyPriority"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Type": fields.Str(required=False, dump_to="Type"),
        "ULBId": fields.Str(required=True, dump_to="ULBId"),
        "VServerId": fields.Str(required=True, dump_to="VServerId"),
    }


class CreatePolicyResponseSchema(schema.ResponseSchema):
    """CreatePolicy - 创建VServer内容转发策略"""

    fields = {
        "PolicyId": fields.Str(required=False, load_from="PolicyId"),
    }


"""
API: CreateSSL

创建SSL证书，可以把整个 Pem 证书内容传过来，或者把证书、私钥、CA证书分别传过来
"""


class CreateSSLRequestSchema(schema.RequestSchema):
    """CreateSSL - 创建SSL证书，可以把整个 Pem 证书内容传过来，或者把证书、私钥、CA证书分别传过来"""

    fields = {
        "CaCert": fields.Str(required=False, dump_to="CaCert"),
        "PrivateKey": fields.Str(required=False, dump_to="PrivateKey"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SSLContent": fields.Str(required=False, dump_to="SSLContent"),
        "SSLName": fields.Str(required=True, dump_to="SSLName"),
        "SSLType": fields.Str(required=False, dump_to="SSLType"),
        "UserCert": fields.Str(required=False, dump_to="UserCert"),
    }


class CreateSSLResponseSchema(schema.ResponseSchema):
    """CreateSSL - 创建SSL证书，可以把整个 Pem 证书内容传过来，或者把证书、私钥、CA证书分别传过来"""

    fields = {
        "SSLId": fields.Str(required=False, load_from="SSLId"),
    }


"""
API: CreateULB

创建负载均衡实例，可以选择内网或者外网
"""


class CreateULBRequestSchema(schema.RequestSchema):
    """CreateULB - 创建负载均衡实例，可以选择内网或者外网"""

    fields = {
        "BusinessId": fields.Str(required=False, dump_to="BusinessId"),
        "ChargeType": fields.Str(required=False, dump_to="ChargeType"),
        "FirewallId": fields.Str(required=False, dump_to="FirewallId"),
        "IPVersion": fields.Str(
            required=False, dump_to="IPVersion"
        ),  # Deprecated, will be removed at 1.0
        "InnerMode": fields.Str(required=False, dump_to="InnerMode"),
        "ListenType": fields.Str(required=False, dump_to="ListenType"),
        "OuterMode": fields.Str(required=False, dump_to="OuterMode"),
        "PrivateIp": fields.Str(
            required=False, dump_to="PrivateIp"
        ),  # Deprecated, will be removed at 1.0
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Remark": fields.Str(required=False, dump_to="Remark"),
        "SubnetId": fields.Str(required=False, dump_to="SubnetId"),
        "Tag": fields.Str(required=False, dump_to="Tag"),
        "ULBName": fields.Str(required=False, dump_to="ULBName"),
        "VPCId": fields.Str(required=False, dump_to="VPCId"),
    }


class CreateULBResponseSchema(schema.ResponseSchema):
    """CreateULB - 创建负载均衡实例，可以选择内网或者外网"""

    fields = {
        "IPv6AddressId": fields.Str(required=False, load_from="IPv6AddressId"),
        "ULBId": fields.Str(required=False, load_from="ULBId"),
    }


"""
API: CreateVServer

创建VServer实例，定义监听的协议和端口以及负载均衡算法
"""


class CreateVServerRequestSchema(schema.RequestSchema):
    """CreateVServer - 创建VServer实例，定义监听的协议和端口以及负载均衡算法"""

    fields = {
        "ClientTimeout": fields.Int(required=False, dump_to="ClientTimeout"),
        "Domain": fields.Str(required=False, dump_to="Domain"),
        "FrontendPort": fields.Int(required=False, dump_to="FrontendPort"),
        "ListenType": fields.Str(required=False, dump_to="ListenType"),
        "Method": fields.Str(required=False, dump_to="Method"),
        "MonitorType": fields.Str(required=False, dump_to="MonitorType"),
        "Path": fields.Str(required=False, dump_to="Path"),
        "PersistenceInfo": fields.Str(
            required=False, dump_to="PersistenceInfo"
        ),
        "PersistenceType": fields.Str(
            required=False, dump_to="PersistenceType"
        ),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Protocol": fields.Str(required=False, dump_to="Protocol"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "RequestMsg": fields.Str(required=False, dump_to="RequestMsg"),
        "ResponseMsg": fields.Str(required=False, dump_to="ResponseMsg"),
        "ULBId": fields.Str(required=True, dump_to="ULBId"),
        "VServerName": fields.Str(required=False, dump_to="VServerName"),
    }


class CreateVServerResponseSchema(schema.ResponseSchema):
    """CreateVServer - 创建VServer实例，定义监听的协议和端口以及负载均衡算法"""

    fields = {
        "VServerId": fields.Str(required=False, load_from="VServerId"),
    }


"""
API: DeletePolicy

删除内容转发策略
"""


class DeletePolicyRequestSchema(schema.RequestSchema):
    """DeletePolicy - 删除内容转发策略"""

    fields = {
        "GroupId": fields.Str(
            required=False, dump_to="GroupId"
        ),  # Deprecated, will be removed at 1.0
        "PolicyId": fields.Str(required=True, dump_to="PolicyId"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "VServerId": fields.Str(required=False, dump_to="VServerId"),
    }


class DeletePolicyResponseSchema(schema.ResponseSchema):
    """DeletePolicy - 删除内容转发策略"""

    fields = {}


"""
API: DeleteSSL

删除SSL证书
"""


class DeleteSSLRequestSchema(schema.RequestSchema):
    """DeleteSSL - 删除SSL证书"""

    fields = {
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SSLId": fields.Str(required=True, dump_to="SSLId"),
    }


class DeleteSSLResponseSchema(schema.ResponseSchema):
    """DeleteSSL - 删除SSL证书"""

    fields = {}


"""
API: DeleteULB

删除负载均衡实例
"""


class DeleteULBRequestSchema(schema.RequestSchema):
    """DeleteULB - 删除负载均衡实例"""

    fields = {
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "ReleaseEip": fields.Bool(required=False, dump_to="ReleaseEip"),
        "ULBId": fields.Str(required=True, dump_to="ULBId"),
    }


class DeleteULBResponseSchema(schema.ResponseSchema):
    """DeleteULB - 删除负载均衡实例"""

    fields = {}


"""
API: DeleteVServer

删除VServer实例
"""


class DeleteVServerRequestSchema(schema.RequestSchema):
    """DeleteVServer - 删除VServer实例"""

    fields = {
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "ULBId": fields.Str(required=True, dump_to="ULBId"),
        "VServerId": fields.Str(required=True, dump_to="VServerId"),
    }


class DeleteVServerResponseSchema(schema.ResponseSchema):
    """DeleteVServer - 删除VServer实例"""

    fields = {}


"""
API: DescribeSSL

获取SSL证书信息
"""


class DescribeSSLRequestSchema(schema.RequestSchema):
    """DescribeSSL - 获取SSL证书信息"""

    fields = {
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SSLId": fields.Str(required=False, dump_to="SSLId"),
    }


class DescribeSSLResponseSchema(schema.ResponseSchema):
    """DescribeSSL - 获取SSL证书信息"""

    fields = {
        "DataSet": fields.List(
            models.ULBSSLSetSchema(), required=False, load_from="DataSet"
        ),
        "TotalCount": fields.Int(required=False, load_from="TotalCount"),
    }


"""
API: DescribeULB

获取ULB详细信息
"""


class DescribeULBRequestSchema(schema.RequestSchema):
    """DescribeULB - 获取ULB详细信息"""

    fields = {
        "BusinessId": fields.Str(required=False, dump_to="BusinessId"),
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SubnetId": fields.Str(required=False, dump_to="SubnetId"),
        "ULBId": fields.Str(required=False, dump_to="ULBId"),
        "VPCId": fields.Str(required=False, dump_to="VPCId"),
    }


class DescribeULBResponseSchema(schema.ResponseSchema):
    """DescribeULB - 获取ULB详细信息"""

    fields = {
        "DataSet": fields.List(
            models.ULBSetSchema(), required=False, load_from="DataSet"
        ),
        "TotalCount": fields.Int(required=False, load_from="TotalCount"),
    }


"""
API: DescribeULBSimple

获取ULB信息
"""


class DescribeULBSimpleRequestSchema(schema.RequestSchema):
    """DescribeULBSimple - 获取ULB信息"""

    fields = {
        "BusinessId": fields.Str(required=False, dump_to="BusinessId"),
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SubnetId": fields.Str(required=False, dump_to="SubnetId"),
        "ULBId": fields.Str(required=False, dump_to="ULBId"),
        "VPCId": fields.Str(required=False, dump_to="VPCId"),
    }


class DescribeULBSimpleResponseSchema(schema.ResponseSchema):
    """DescribeULBSimple - 获取ULB信息"""

    fields = {
        "DataSet": fields.List(
            models.ULBSimpleSetSchema(), required=True, load_from="DataSet"
        ),
        "TotalCount": fields.Int(required=True, load_from="TotalCount"),
    }


"""
API: DescribeVServer

获取ULB下的VServer的详细信息
"""


class DescribeVServerRequestSchema(schema.RequestSchema):
    """DescribeVServer - 获取ULB下的VServer的详细信息"""

    fields = {
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "ULBId": fields.Str(required=False, dump_to="ULBId"),
        "VServerId": fields.Str(required=False, dump_to="VServerId"),
    }


class DescribeVServerResponseSchema(schema.ResponseSchema):
    """DescribeVServer - 获取ULB下的VServer的详细信息"""

    fields = {
        "DataSet": fields.List(
            models.ULBVServerSetSchema(), required=False, load_from="DataSet"
        ),
        "TotalCount": fields.Int(required=False, load_from="TotalCount"),
    }


"""
API: ReleaseBackend

从VServer释放后端资源实例
"""


class ReleaseBackendRequestSchema(schema.RequestSchema):
    """ReleaseBackend - 从VServer释放后端资源实例"""

    fields = {
        "BackendId": fields.Str(required=True, dump_to="BackendId"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "ULBId": fields.Str(required=True, dump_to="ULBId"),
    }


class ReleaseBackendResponseSchema(schema.ResponseSchema):
    """ReleaseBackend - 从VServer释放后端资源实例"""

    fields = {}


"""
API: UnbindSSL

从VServer解绑SSL证书
"""


class UnbindSSLRequestSchema(schema.RequestSchema):
    """UnbindSSL - 从VServer解绑SSL证书"""

    fields = {
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SSLId": fields.Str(required=True, dump_to="SSLId"),
        "ULBId": fields.Str(required=True, dump_to="ULBId"),
        "VServerId": fields.Str(required=True, dump_to="VServerId"),
    }


class UnbindSSLResponseSchema(schema.ResponseSchema):
    """UnbindSSL - 从VServer解绑SSL证书"""

    fields = {}


"""
API: UpdateBackendAttribute

更新ULB后端资源实例(服务节点)属性
"""


class UpdateBackendAttributeRequestSchema(schema.RequestSchema):
    """UpdateBackendAttribute - 更新ULB后端资源实例(服务节点)属性"""

    fields = {
        "BackendId": fields.Str(required=True, dump_to="BackendId"),
        "Enabled": fields.Int(required=False, dump_to="Enabled"),
        "IsBackup": fields.Int(required=False, dump_to="IsBackup"),
        "Port": fields.Int(required=False, dump_to="Port"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "ULBId": fields.Str(required=True, dump_to="ULBId"),
        "Weight": fields.Int(required=False, dump_to="Weight"),
    }


class UpdateBackendAttributeResponseSchema(schema.ResponseSchema):
    """UpdateBackendAttribute - 更新ULB后端资源实例(服务节点)属性"""

    fields = {}


"""
API: UpdatePolicy

更新内容转发规则，包括转发规则后的服务节点
"""


class UpdatePolicyRequestSchema(schema.RequestSchema):
    """UpdatePolicy - 更新内容转发规则，包括转发规则后的服务节点"""

    fields = {
        "BackendId": fields.List(fields.Str()),
        "Match": fields.Str(required=True, dump_to="Match"),
        "PolicyId": fields.Str(required=False, dump_to="PolicyId"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Type": fields.Str(required=False, dump_to="Type"),
        "ULBId": fields.Str(required=True, dump_to="ULBId"),
        "VServerId": fields.Str(required=True, dump_to="VServerId"),
    }


class UpdatePolicyResponseSchema(schema.ResponseSchema):
    """UpdatePolicy - 更新内容转发规则，包括转发规则后的服务节点"""

    fields = {
        "PolicyId": fields.Str(
            required=False, load_from="PolicyId"
        ),  # Deprecated, will be removed at 1.0
    }


"""
API: UpdateSSLAttribute

更新修改SSL的属性，如：修改SSLName
"""


class UpdateSSLAttributeRequestSchema(schema.RequestSchema):
    """UpdateSSLAttribute - 更新修改SSL的属性，如：修改SSLName"""

    fields = {
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SSLId": fields.Str(required=True, dump_to="SSLId"),
        "SSLName": fields.Str(required=True, dump_to="SSLName"),
    }


class UpdateSSLAttributeResponseSchema(schema.ResponseSchema):
    """UpdateSSLAttribute - 更新修改SSL的属性，如：修改SSLName"""

    fields = {}


"""
API: UpdateULBAttribute

更新ULB名字业务组备注等属性字段
"""


class UpdateULBAttributeRequestSchema(schema.RequestSchema):
    """UpdateULBAttribute - 更新ULB名字业务组备注等属性字段"""

    fields = {
        "Name": fields.Str(required=False, dump_to="Name"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Remark": fields.Str(required=False, dump_to="Remark"),
        "Tag": fields.Str(required=False, dump_to="Tag"),
        "ULBId": fields.Str(required=True, dump_to="ULBId"),
    }


class UpdateULBAttributeResponseSchema(schema.ResponseSchema):
    """UpdateULBAttribute - 更新ULB名字业务组备注等属性字段"""

    fields = {}


"""
API: UpdateVServerAttribute

更新VServer实例属性
"""


class UpdateVServerAttributeRequestSchema(schema.RequestSchema):
    """UpdateVServerAttribute - 更新VServer实例属性"""

    fields = {
        "ClientTimeout": fields.Int(required=False, dump_to="ClientTimeout"),
        "Domain": fields.Str(required=False, dump_to="Domain"),
        "Method": fields.Str(required=False, dump_to="Method"),
        "MonitorType": fields.Str(required=False, dump_to="MonitorType"),
        "Path": fields.Str(required=False, dump_to="Path"),
        "PersistenceInfo": fields.Str(
            required=False, dump_to="PersistenceInfo"
        ),
        "PersistenceType": fields.Str(
            required=False, dump_to="PersistenceType"
        ),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Protocol": fields.Str(
            required=False, dump_to="Protocol"
        ),  # Deprecated, will be removed at 1.0
        "Region": fields.Str(required=True, dump_to="Region"),
        "RequestMsg": fields.Str(required=False, dump_to="RequestMsg"),
        "ResponseMsg": fields.Str(required=False, dump_to="ResponseMsg"),
        "ULBId": fields.Str(required=True, dump_to="ULBId"),
        "VServerId": fields.Str(required=True, dump_to="VServerId"),
        "VServerName": fields.Str(required=False, dump_to="VServerName"),
    }


class UpdateVServerAttributeResponseSchema(schema.ResponseSchema):
    """UpdateVServerAttribute - 更新VServer实例属性"""

    fields = {}



import logging

DEFAULT_LOGGER_NAME = "ucloud"
DEFAULT_FORMAT = "%(asctime)s [%(levelname)8s] %(message)s (%(filename)s:%(lineno)s %(name)s)"
DEFAULT_LEVEL = logging.INFO


def init_default_logger():
    logger = logging.getLogger(DEFAULT_LOGGER_NAME)
    logger.setLevel(DEFAULT_LEVEL)

    # create console handler and set level to debug
    ch = logging.StreamHandler()
    ch.setLevel(DEFAULT_LEVEL)

    # create formatter
    formatter = logging.Formatter(DEFAULT_FORMAT)

    # add formatter to ch
    ch.setFormatter(formatter)

    # add ch to logger
    logger.removeHandler(ch)
    logger.addHandler(ch)

    return logger


default_logger = init_default_logger()



""" Code is generated by ucloud-model, DO NOT EDIT IT. """

import typing


from ucloud.core.client import Client
from ucloud.services.urocketmq.schemas import apis


class URocketMQClient(Client):
    def __init__(
        self, config: dict, transport=None, middleware=None, logger=None
    ):
        super(URocketMQClient, self).__init__(
            config, transport, middleware, logger
        )

    def create_u_rocket_mq_group(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """CreateURocketMQGroup - 创建一个 Group, 如果同名 Group 在当前 Service 中已存在, 则会失败.

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **Name** (str) - (Required) Group 名称，支持大小写字母、数字及-, _ ，长度1~36
        - **ServiceId** (str) - (Required) Service ID
        - **Remark** (str) - Group 描述.

        **Response**

        - **GroupId** (str) - 新建 Group 的 ID
        - **Message** (str) - 返回信息

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.CreateURocketMQGroupRequestSchema().dumps(d)

        # build options
        kwargs["max_retries"] = 0  # ignore retry when api is not idempotent

        resp = self.invoke("CreateURocketMQGroup", d, **kwargs)
        return apis.CreateURocketMQGroupResponseSchema().loads(resp)

    def delete_u_rocket_mq_group(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """DeleteURocketMQGroup - 删除一个已存在的 Group

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **GroupName** (str) - (Required) Group名称
        - **ServiceId** (str) - (Required) Service ID

        **Response**

        - **Message** (str) - 返回信息

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.DeleteURocketMQGroupRequestSchema().dumps(d)

        resp = self.invoke("DeleteURocketMQGroup", d, **kwargs)
        return apis.DeleteURocketMQGroupResponseSchema().loads(resp)

    def list_u_rocket_mq_group(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """ListURocketMQGroup - 获取一个 RocketMQ 服务下的所有 Group

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **ServiceId** (str) - (Required) Service ID
        - **Limit** (int) - 最多返回的条目数量, (0, 1000], 默认 50 条
        - **Offset** (int) - 查询起始位置, [0, ∞)

        **Response**

        - **GroupList** (list) - 见 **GroupBaseInfo** 模型定义
        - **Message** (str) - 返回信息
        - **TotalCount** (int) - 记录总数

        **Response Model**

        **GroupBaseInfo**
        - **CreateTime** (int) - Group 创建时间
        - **GroupName** (str) - Group 名称
        - **Id** (str) - Group ID
        - **Remark** (str) - Group 描述


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.ListURocketMQGroupRequestSchema().dumps(d)

        resp = self.invoke("ListURocketMQGroup", d, **kwargs)
        return apis.ListURocketMQGroupResponseSchema().loads(resp)



""" Code is generated by ucloud-model, DO NOT EDIT IT. """

import typing


from ucloud.core.client import Client
from ucloud.services.cube.schemas import apis


class CubeClient(Client):
    def __init__(
        self, config: dict, transport=None, middleware=None, logger=None
    ):
        super(CubeClient, self).__init__(config, transport, middleware, logger)

    def create_cube_deployment(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """CreateCubeDeployment - 创建Cube的Deployment

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **Deployment** (str) - (Required) base64编码的Deployment的yaml。大小不超过16KB
        - **SubnetId** (str) - (Required) 子网Id
        - **VPCId** (str) - (Required) VPCId
        - **Zone** (str) - (Required) 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **ChargeType** (str) - 计费模式。枚举值为： \\ > Year，按年付费； \\ > Month，按月付费；\\ > Postpay， \\ 后付费；默认为后付费
        - **CpuPlatform** (str) - Cpu平台（V6：Intel、A2：AMD），默认V6。支持的地域（北京2B、北京2E、上海2A、广东、香港 、东京）目前北京2E仅有A2，其余地域仅有V6
        - **KubeConfig** (str) - base64编码的kubeconfig。大小不超过16KB
        - **Name** (str) - Deployment名称
        - **Quantity** (int) - 购买时长。默认:值 1。 月付时，此参数传0，代表购买至月末。
        - **Tag** (str) - 业务组。默认：Default（Default即为未分组）

        **Response**

        - **Deployment** (str) - 经过base64编码的Deployment的yaml
        - **DeploymentId** (str) - 控制器ID

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.CreateCubeDeploymentRequestSchema().dumps(d)

        # build options
        kwargs["max_retries"] = 0  # ignore retry when api is not idempotent

        resp = self.invoke("CreateCubeDeployment", d, **kwargs)
        return apis.CreateCubeDeploymentResponseSchema().loads(resp)

    def create_cube_pod(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """CreateCubePod - 创建Pod

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **Pod** (str) - (Required) base64编码的Pod的yaml。大小不超过16KB
        - **SubnetId** (str) - (Required) 子网Id
        - **VPCId** (str) - (Required) VPCId
        - **Zone** (str) - (Required) 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **ChargeType** (str) - 计费模式。枚举值为： \\ > Year，按年付费； \\ > Month，按月付费；\\ > Postpay， \\ 后付费；默认为后付费
        - **CouponId** (str) - 代金券ID。请通过DescribeCoupon接口查询，或登录用户中心查看
        - **CpuPlatform** (str) - Cpu平台（V6：Intel、A2：AMD、Auto），默认Auto。支持的地域（北京2B、北京2E、上海2A、广东、香港 、东京）目前北京2E仅有A2，其余地域仅有V6
        - **Group** (str) - pod所在组
        - **KubeConfig** (str) - base64编码的kubeconfig。大小不超过16KB
        - **Name** (str) - pod的名字
        - **Quantity** (int) - 购买时长。默认:值 1。 月付时，此参数传0，代表购买至月末。
        - **Tag** (str) - 业务组。默认：Default（Default即为未分组）

        **Response**

        - **CubeId** (str) - cube的资源Id
        - **Pod** (str) - base64编码的yaml

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.CreateCubePodRequestSchema().dumps(d)

        # build options
        kwargs["max_retries"] = 0  # ignore retry when api is not idempotent

        resp = self.invoke("CreateCubePod", d, **kwargs)
        return apis.CreateCubePodResponseSchema().loads(resp)

    def delete_cube_deployment(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """DeleteCubeDeployment - 删除Cube的Deployment

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **DeploymentId** (str) - (Required) 控制器Id
        - **Zone** (str) - 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_

        **Response**


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.DeleteCubeDeploymentRequestSchema().dumps(d)

        resp = self.invoke("DeleteCubeDeployment", d, **kwargs)
        return apis.DeleteCubeDeploymentResponseSchema().loads(resp)

    def delete_cube_pod(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """DeleteCubePod - 删除Pod

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_
        - **CubeId** (str) - cubeid和uid任意一个（必须）
        - **ReleaseEIP** (bool) - 删除cube时是否释放绑定的EIP。默认为false。
        - **Uid** (str) - cubeid和uid任意一个（必须）
        - **Zone** (str) - 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_

        **Response**


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.DeleteCubePodRequestSchema().dumps(d)

        resp = self.invoke("DeleteCubePod", d, **kwargs)
        return apis.DeleteCubePodResponseSchema().loads(resp)

    def get_cube_deployment(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """GetCubeDeployment - 获取Deployment的详细信息

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **DeploymentId** (str) - (Required) Deployment的Id
        - **Zone** (str) - 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_

        **Response**

        - **Deployment** (str) - 经过base64编码的Deployment的yaml

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.GetCubeDeploymentRequestSchema().dumps(d)

        resp = self.invoke("GetCubeDeployment", d, **kwargs)
        return apis.GetCubeDeploymentResponseSchema().loads(resp)

    def get_cube_exec_token(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """GetCubeExecToken - 获取登录容器的token

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **ContainerName** (str) - (Required) 容器名称
        - **CubeId** (str) - CubeId 和 Uid 中必须填写任意一个。CubeId 是所有 Cube 资源的唯一 ID，如非在 UK8S 通过 Virtual Kubelet 插件创建的 Cube， 则必填 CubeId
        - **Uid** (str) - CubeId 和 Uid 中必须填写任意一个。Uid 是在 UK8S 中通过 Virtual Kubelet 插件创建出的 Cube 的唯一标识
        - **Zone** (str) - 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_

        **Response**

        - **TerminalUrl** (str) - terminal的登录连接地址，限单点登录，有效时间5min
        - **Token** (str) - 有效时间5min

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.GetCubeExecTokenRequestSchema().dumps(d)

        resp = self.invoke("GetCubeExecToken", d, **kwargs)
        return apis.GetCubeExecTokenResponseSchema().loads(resp)

    def get_cube_extend_info(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """GetCubeExtendInfo - 获取Cube的额外信息

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_
        - **CubeIds** (str) - (Required) id列表以逗号(,)分割
        - **Zone** (str) - 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_

        **Response**

        - **ExtendInfo** (list) - 见 **CubeExtendInfo** 模型定义

        **Response Model**

        **CubeExtendInfo**
        - **CubeId** (str) - Cube的Id
        - **Eip** (list) - 见 **EIPSet** 模型定义
        - **Expiration** (int) - 资源有效期
        - **Name** (str) - Cube的名称
        - **Tag** (str) - 业务组名称


        **EIPSet**
        - **Bandwidth** (int) - EIP带宽值
        - **BandwidthType** (int) - 带宽类型0标准普通带宽，1表示共享带宽
        - **CreateTime** (int) - EIP创建时间
        - **EIPAddr** (list) - 见 **EIPAddr** 模型定义
        - **EIPId** (str) - EIPId
        - **PayMode** (str) - 付费模式，带宽付费或者流量付费
        - **Resource** (str) - EIP绑定对象的资源Id
        - **Status** (str) - EIP状态，表示使用中或者空闲
        - **Weight** (int) - EIP权重


        **EIPAddr**
        - **IP** (str) - IP地址
        - **OperatorName** (str) - 线路名称BGP或者internalation


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.GetCubeExtendInfoRequestSchema().dumps(d)

        resp = self.invoke("GetCubeExtendInfo", d, **kwargs)
        return apis.GetCubeExtendInfoResponseSchema().loads(resp)

    def get_cube_metrics(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """GetCubeMetrics - 获取Cube实例（Pod，PodX，Deploy等）监控数据时间序列

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **BeginTime** (int) - (Required) 开始时间
        - **ContainerName** (str) - (Required) Pod内容器名称
        - **EndTime** (int) - (Required) 结束时间，必须大于开始时间
        - **MetricName** (list) - (Required) 监控指标名称
        - **ResourceId** (str) - (Required) Cube实例资源ID
        - **Zone** (str) - (Required) 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_

        **Response**

        - **DataSets** (list) - 见 **MetricDataSet** 模型定义
        - **Message** (str) - 错误信息

        **Response Model**

        **MetricDataSet**
        - **MetricName** (str) -
        - **Values** (list) - 见 **ValueSet** 模型定义


        **ValueSet**
        - **Timestamp** (int) -
        - **Value** (float) -


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.GetCubeMetricsRequestSchema().dumps(d)

        resp = self.invoke("GetCubeMetrics", d, **kwargs)
        return apis.GetCubeMetricsResponseSchema().loads(resp)

    def get_cube_pod(self, req: typing.Optional[dict] = None, **kwargs) -> dict:
        """GetCubePod - 获取Pod的详细信息

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_
        - **CubeId** (str) - CubeId和Uid任意一个
        - **Uid** (str) - CubeId和Uid任意一个
        - **Zone** (str) - 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_

        **Response**

        - **Pod** (str) - base64编码的pod的yaml

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.GetCubePodRequestSchema().dumps(d)

        resp = self.invoke("GetCubePod", d, **kwargs)
        return apis.GetCubePodResponseSchema().loads(resp)

    def get_cube_price(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """GetCubePrice - 获取cube的价格

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **ChargeType** (str) - (Required) 计费模式。枚举值为： \\ > Year，按年付费； \\ > Month，按月付费；\\ > Dynamic，按小时预付费 \\ > Postpay，按秒后付费，默认为月付
        - **Count** (str) - (Required) 购买数量
        - **Cpu** (str) - (Required) CPU 配置，单位为毫核，例如如 1 核则须输入 1000
        - **Mem** (str) - (Required) 内存配置，单位为 Mi，例如 1Gi 须输入 1024
        - **Quantity** (int) - (Required) 购买时长。默认:值 1。按小时购买（Dynamic/Postpay）时无需此参数。 月付时，此参数传0，代表购买至月末。
        - **Zone** (str) - (Required) 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_

        **Response**

        - **OriginalPrice** (int) - 列表价格，单位为分
        - **Price** (int) - 折扣后价格，单位为分

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.GetCubePriceRequestSchema().dumps(d)

        resp = self.invoke("GetCubePrice", d, **kwargs)
        return apis.GetCubePriceResponseSchema().loads(resp)

    def get_cube_token(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """GetCubeToken - 获取Cube的token，可用于terminal登录、log获取

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **ContainerName** (str) - (Required) 容器名称
        - **CubeId** (str) - CubeId 和 Uid 中必须填写任意一个。CubeId 是所有 Cube 资源的唯一 ID，如非在 UK8S 通过 Virtual Kubelet 插件创建的 Cube， 则必填 CubeId
        - **Uid** (str) - CubeId 和 Uid 中必须填写任意一个。Uid 是在 UK8S 中通过 Virtual Kubelet 插件创建出的 Cube 的唯一标识
        - **Zone** (str) - 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_

        **Response**

        - **Token** (str) - 有效时间5min

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.GetCubeTokenRequestSchema().dumps(d)

        resp = self.invoke("GetCubeToken", d, **kwargs)
        return apis.GetCubeTokenResponseSchema().loads(resp)

    def list_cube_deployment(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """ListCubeDeployment - 获取Cube的Deployment列表

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **Limit** (int) - (Required) 默认20
        - **Offset** (int) - (Required) 默认0
        - **Zone** (str) - 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_

        **Response**

        - **Deployments** (list) - DeploymentInfo
        - **TotalCount** (int) -

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.ListCubeDeploymentRequestSchema().dumps(d)

        resp = self.invoke("ListCubeDeployment", d, **kwargs)
        return apis.ListCubeDeploymentResponseSchema().loads(resp)

    def list_cube_pod(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """ListCubePod - 获取Pods列表

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **DeploymentId** (str) - Deployment的Id
        - **Group** (str) - 组名称
        - **Limit** (int) - 默认20
        - **Offset** (int) - 默认0
        - **SubnetId** (str) - 子网Id
        - **VPCId** (str) - VPC的Id
        - **Zone** (str) - 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_

        **Response**

        - **Pods** (list) - Pod列表，每条数据都做了base64编码
        - **TotalCount** (int) - Cube的总数

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.ListCubePodRequestSchema().dumps(d)

        resp = self.invoke("ListCubePod", d, **kwargs)
        return apis.ListCubePodResponseSchema().loads(resp)

    def modify_cube_extend_info(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """ModifyCubeExtendInfo - 修改Cube额外信息

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_
        - **CubeId** (str) - (Required) cube的id
        - **Name** (str) - 修改的名字，规则（^[a-zA-Z0-9-_.\u4e00-\u9fa5]{1,32}）
        - **Zone** (str) - 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_

        **Response**


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.ModifyCubeExtendInfoRequestSchema().dumps(d)

        resp = self.invoke("ModifyCubeExtendInfo", d, **kwargs)
        return apis.ModifyCubeExtendInfoResponseSchema().loads(resp)

    def modify_cube_tag(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """ModifyCubeTag - 修改业务组名字

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **CubeId** (str) - (Required) CubeId
        - **Tag** (str) - (Required) 业务组名称
        - **Zone** (str) - 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_

        **Response**

        - **CubeId** (str) - CubeId

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.ModifyCubeTagRequestSchema().dumps(d)

        resp = self.invoke("ModifyCubeTag", d, **kwargs)
        return apis.ModifyCubeTagResponseSchema().loads(resp)

    def reboot_cube_pod(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """RebootCubePod - 重启Cube Pod

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **CubeId** (str) - (Required) cube资源id（cube-xxxxxx）
        - **Zone** (str) - 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_

        **Response**


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.RebootCubePodRequestSchema().dumps(d)

        resp = self.invoke("RebootCubePod", d, **kwargs)
        return apis.RebootCubePodResponseSchema().loads(resp)

    def renew_cube_pod(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """RenewCubePod - 更新Pod

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_
        - **CubeId** (str) - (Required) 容器Id
        - **Pod** (str) - (Required) base64编码的Pod的yaml
        - **Zone** (str) - 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_

        **Response**

        - **Pod** (str) - base64编码过的yaml，需要解码获取信息

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.RenewCubePodRequestSchema().dumps(d)

        resp = self.invoke("RenewCubePod", d, **kwargs)
        return apis.RenewCubePodResponseSchema().loads(resp)

    def update_cube_deployment(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """UpdateCubeDeployment - 更新Deployment

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **Deployment** (str) - (Required) base64编码的Deployment的yaml。大小不超过16KB
        - **DeploymentId** (str) - (Required) Deployment的Id
        - **Name** (str) - Deployment的name
        - **Zone** (str) - 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_

        **Response**

        - **Deployment** (str) - 经过base64编码的Deployment的yaml

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.UpdateCubeDeploymentRequestSchema().dumps(d)

        resp = self.invoke("UpdateCubeDeployment", d, **kwargs)
        return apis.UpdateCubeDeploymentResponseSchema().loads(resp)



import hashlib
from collections import OrderedDict
from ucloud.core.typesystem import schema, fields, encoder


class CredentialSchema(schema.Schema):
    fields = {
        "public_key": fields.Str(required=True),
        "private_key": fields.Str(required=True),
    }


def verify_ac(private_key: str, params: dict) -> str:
    """calculate signature by private_key/public_key

    the keys can be found on `APIKey documentation <https://console.ucloud.cn/uapi/apikey>`__

    >>> verify_ac("my_private_key", {"foo": "bar"})
    '634edc1bb957c0d65e5ab5494cf3b7784fbc87af'

    >>> verify_ac("my_private_key", {"foo": "bar"})
    '634edc1bb957c0d65e5ab5494cf3b7784fbc87af'

    :param private_key: private key
    :param params:
    :return:
    """
    params = OrderedDict(sorted(params.items(), key=lambda item: item[0]))

    simplified = ""
    for key, value in params.items():
        simplified += str(key) + encoder.encode_value(value)
    simplified += private_key

    hash_new = hashlib.sha1()
    hash_new.update(simplified.encode("utf-8"))
    hash_value = hash_new.hexdigest()
    return hash_value


class Credential:
    """credential is the object to store credential information

    the keys can be found on `APIKey documentation <https://console.ucloud.cn/uapi/apikey>`__

    it can calculate signature for OpenAPI:

    >>> cred = Credential('my_public_key', 'my_private_key')
    >>> cred.verify_ac({"foo": "bar"})
    'd4411ab30953fb0bbcb1e7313081f05e4e91a394'

    :param public_key:
    :param private_key:
    """

    PUBLIC_KEY_NAME = "PublicKey"

    def __init__(self, public_key: str, private_key: str, **kwargs):
        self.public_key = public_key
        self.private_key = private_key

    def verify_ac(self, args: dict) -> str:
        args[Credential.PUBLIC_KEY_NAME] = self.public_key
        return verify_ac(self.private_key, args)

    @classmethod
    def from_dict(cls, d: dict):
        parsed = CredentialSchema().dumps(d)
        return cls(**parsed)

    def to_dict(self) -> dict:
        return {"public_key": self.public_key, "private_key": self.private_key}



""" Code is generated by ucloud-model, DO NOT EDIT IT. """


from ucloud.core.typesystem import schema, fields
from ucloud.services.tidb.schemas import models

""" TiDB API Schema
"""


"""
API: CreateTiDBService

创建TiDB服务
"""


class CreateTiDBServiceRequestSchema(schema.RequestSchema):
    """CreateTiDBService - 创建TiDB服务"""

    fields = {
        "DTType": fields.Str(required=False, dump_to="DTType"),
        "Ip": fields.Str(required=False, dump_to="Ip"),
        "Name": fields.Str(required=True, dump_to="Name"),
        "Password": fields.Str(required=True, dump_to="Password"),
        "Port": fields.Str(required=False, dump_to="Port"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SubnetId": fields.Str(required=True, dump_to="SubnetId"),
        "TikvMemoryHardTh": fields.Str(
            required=False, dump_to="TikvMemoryHardTh"
        ),
        "VPCId": fields.Str(required=True, dump_to="VPCId"),
    }


class CreateTiDBServiceResponseSchema(schema.ResponseSchema):
    """CreateTiDBService - 创建TiDB服务"""

    fields = {
        "Data": models.ServiceIDSchema(),
        "Message": fields.Str(required=False, load_from="Message"),
        "ServiceId": fields.Str(required=False, load_from="ServiceId"),
    }


"""
API: DeleteTiDBService

删除一个服务
"""


class DeleteTiDBServiceRequestSchema(schema.RequestSchema):
    """DeleteTiDBService - 删除一个服务"""

    fields = {
        "Id": fields.Str(required=True, dump_to="Id"),
        "Region": fields.Str(required=True, dump_to="Region"),
    }


class DeleteTiDBServiceResponseSchema(schema.ResponseSchema):
    """DeleteTiDBService - 删除一个服务"""

    fields = {
        "Message": fields.Str(required=True, load_from="Message"),
        "ServiceId": fields.Str(required=False, load_from="ServiceId"),
    }


"""
API: SetTiDBConfig

设置TiDB服务实例参数
"""


class SetTiDBConfigParamConfigsSchema(schema.RequestSchema):
    """SetTiDBConfigParamConfigs -"""

    fields = {
        "Name": fields.Str(required=True, dump_to="Name"),
        "Value": fields.Str(required=True, dump_to="Value"),
    }


class SetTiDBConfigRequestSchema(schema.RequestSchema):
    """SetTiDBConfig - 设置TiDB服务实例参数"""

    fields = {
        "Configs": fields.List(SetTiDBConfigParamConfigsSchema()),
        "Id": fields.Str(required=True, dump_to="Id"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
    }


class SetTiDBConfigResponseSchema(schema.ResponseSchema):
    """SetTiDBConfig - 设置TiDB服务实例参数"""

    fields = {
        "ServiceId": fields.Str(required=False, load_from="ServiceId"),
    }



""" Code is generated by ucloud-model, DO NOT EDIT IT. """


from ucloud.core.typesystem import schema, fields
from ucloud.services.uvms.schemas import models

""" UVMS API Schema
"""


"""
API: SendUVMSMessage

向指定号码拨打电话
"""


class SendUVMSMessageRequestSchema(schema.RequestSchema):
    """SendUVMSMessage - 向指定号码拨打电话"""

    fields = {
        "CalledNumber": fields.Str(required=True, dump_to="CalledNumber"),
        "DispatchRule": fields.Int(required=False, dump_to="DispatchRule"),
        "FromNumber": fields.Str(required=False, dump_to="FromNumber"),
        "GroupType": fields.Int(required=False, dump_to="GroupType"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(
            required=True, dump_to="Region"
        ),  # Deprecated, will be removed at 1.0
        "TemplateId": fields.Str(required=True, dump_to="TemplateId"),
        "TemplateParams": fields.List(fields.Str()),
        "UserId": fields.Str(required=False, dump_to="UserId"),
        "Zone": fields.Str(
            required=True, dump_to="Zone"
        ),  # Deprecated, will be removed at 1.0
    }


class SendUVMSMessageResponseSchema(schema.ResponseSchema):
    """SendUVMSMessage - 向指定号码拨打电话"""

    fields = {
        "Message": fields.Str(required=True, load_from="Message"),
        "ReqUuid": fields.Str(required=True, load_from="ReqUuid"),
        "SessionNo": fields.Str(required=False, load_from="SessionNo"),
        "UserId": fields.Str(required=False, load_from="UserId"),
    }



""" Code is generated by ucloud-model, DO NOT EDIT IT. """

from ucloud.core.typesystem import schema, fields
from ucloud.services.stepflow.schemas import models


""" StepFlow API Schema
"""


"""
API: CreateSFWorkflowFromTemplate

导入工作流定义
"""


class CreateSFWorkflowFromTemplateRequestSchema(schema.RequestSchema):
    """CreateSFWorkflowFromTemplate - 导入工作流定义"""

    fields = {
        "Namespace": fields.Str(required=True, dump_to="Namespace"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Workflow": fields.Base64(required=True, dump_to="Workflow"),
        "WorkflowName": fields.Str(required=True, dump_to="WorkflowName"),
    }


class CreateSFWorkflowFromTemplateResponseSchema(schema.ResponseSchema):
    """CreateSFWorkflowFromTemplate - 导入工作流定义"""

    fields = {
        "Message": fields.Str(required=True, load_from="Message"),
        "Version": fields.Int(required=True, load_from="Version"),
    }


"""
API: GetSFWorkflowTemplate

导出工作流定义
"""


class GetSFWorkflowTemplateRequestSchema(schema.RequestSchema):
    """GetSFWorkflowTemplate - 导出工作流定义"""

    fields = {
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "WorkflowId": fields.Str(required=True, dump_to="WorkflowId"),
        "WorkflowVersion": fields.Int(
            required=False, dump_to="WorkflowVersion"
        ),
    }


class GetSFWorkflowTemplateResponseSchema(schema.ResponseSchema):
    """GetSFWorkflowTemplate - 导出工作流定义"""

    fields = {
        "Message": fields.Str(required=False, load_from="Message"),
        "Version": fields.Int(required=True, load_from="Version"),
        "Workflow": models.WorkflowTemplateSchema(),
        "WorkflowId": fields.Str(required=True, load_from="WorkflowId"),
    }



""" Code is generated by ucloud-model, DO NOT EDIT IT. """


from ucloud.core.typesystem import schema, fields
from ucloud.services.usms.schemas import models

""" USMS API Schema
"""


"""
API: CreateUSMSSignature

调用接口CreateUSMSSignature申请短信签名
"""


class CreateUSMSSignatureRequestSchema(schema.RequestSchema):
    """CreateUSMSSignature - 调用接口CreateUSMSSignature申请短信签名"""

    fields = {
        "CertificateType": fields.Int(required=True, dump_to="CertificateType"),
        "Description": fields.Str(required=True, dump_to="Description"),
        "File": fields.Str(required=True, dump_to="File"),
        "International": fields.Bool(required=False, dump_to="International"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "ProxyFile": fields.Str(required=False, dump_to="ProxyFile"),
        "SigContent": fields.Str(required=True, dump_to="SigContent"),
        "SigPurpose": fields.Int(required=True, dump_to="SigPurpose"),
        "SigType": fields.Int(required=True, dump_to="SigType"),
    }


class CreateUSMSSignatureResponseSchema(schema.ResponseSchema):
    """CreateUSMSSignature - 调用接口CreateUSMSSignature申请短信签名"""

    fields = {
        "Message": fields.Str(required=True, load_from="Message"),
        "SigContent": fields.Str(
            required=False, load_from="SigContent"
        ),  # Deprecated, will be removed at 1.0
        "SigId": fields.Str(required=False, load_from="SigId"),
    }


"""
API: CreateUSMSTemplate

调用接口CreateUSMSTemplate申请短信模板
"""


class CreateUSMSTemplateRequestSchema(schema.RequestSchema):
    """CreateUSMSTemplate - 调用接口CreateUSMSTemplate申请短信模板"""

    fields = {
        "Instruction": fields.Str(required=False, dump_to="Instruction"),
        "International": fields.Bool(required=False, dump_to="International"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Purpose": fields.Int(required=True, dump_to="Purpose"),
        "Region": fields.Str(
            required=False, dump_to="Region"
        ),  # Deprecated, will be removed at 1.0
        "Remark": fields.Str(required=False, dump_to="Remark"),
        "Template": fields.Str(required=True, dump_to="Template"),
        "TemplateName": fields.Str(required=True, dump_to="TemplateName"),
        "UnsubscribeInfo": fields.Str(
            required=False, dump_to="UnsubscribeInfo"
        ),
        "Zone": fields.Str(
            required=False, dump_to="Zone"
        ),  # Deprecated, will be removed at 1.0
    }


class CreateUSMSTemplateResponseSchema(schema.ResponseSchema):
    """CreateUSMSTemplate - 调用接口CreateUSMSTemplate申请短信模板"""

    fields = {
        "Message": fields.Str(required=True, load_from="Message"),
        "TemplateId": fields.Str(required=True, load_from="TemplateId"),
    }


"""
API: DeleteUSMSSignature

调用接口DeleteUSMSSignature删除短信签名
"""


class DeleteUSMSSignatureRequestSchema(schema.RequestSchema):
    """DeleteUSMSSignature - 调用接口DeleteUSMSSignature删除短信签名"""

    fields = {
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "SigIds": fields.List(fields.Str()),
    }


class DeleteUSMSSignatureResponseSchema(schema.ResponseSchema):
    """DeleteUSMSSignature - 调用接口DeleteUSMSSignature删除短信签名"""

    fields = {
        "Message": fields.Str(required=True, load_from="Message"),
    }


"""
API: DeleteUSMSTemplate

调用接口DeleteUSMSTemplate删除短信模板
"""


class DeleteUSMSTemplateRequestSchema(schema.RequestSchema):
    """DeleteUSMSTemplate - 调用接口DeleteUSMSTemplate删除短信模板"""

    fields = {
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(
            required=False, dump_to="Region"
        ),  # Deprecated, will be removed at 1.0
        "TemplateIds": fields.List(fields.Str()),
        "Zone": fields.Str(
            required=False, dump_to="Zone"
        ),  # Deprecated, will be removed at 1.0
    }


class DeleteUSMSTemplateResponseSchema(schema.ResponseSchema):
    """DeleteUSMSTemplate - 调用接口DeleteUSMSTemplate删除短信模板"""

    fields = {
        "Message": fields.Str(required=True, load_from="Message"),
    }


"""
API: GetUSMSSendReceipt

调用接口GetUSMSSendReceipt短信发送状态信息
"""


class GetUSMSSendReceiptRequestSchema(schema.RequestSchema):
    """GetUSMSSendReceipt - 调用接口GetUSMSSendReceipt短信发送状态信息"""

    fields = {
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=False, dump_to="Region"),
        "SessionNoSet": fields.List(fields.Str()),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class GetUSMSSendReceiptResponseSchema(schema.ResponseSchema):
    """GetUSMSSendReceipt - 调用接口GetUSMSSendReceipt短信发送状态信息"""

    fields = {
        "Data": fields.List(
            models.ReceiptPerSessionSchema(), required=True, load_from="Data"
        ),
        "Message": fields.Str(required=True, load_from="Message"),
    }


"""
API: QueryUSMSSignature

调用接口QueryUSMSSignature查询短信签名申请状态
"""


class QueryUSMSSignatureRequestSchema(schema.RequestSchema):
    """QueryUSMSSignature - 调用接口QueryUSMSSignature查询短信签名申请状态"""

    fields = {
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "SigContent": fields.Str(required=False, dump_to="SigContent"),
        "SigId": fields.Str(required=False, dump_to="SigId"),
    }


class QueryUSMSSignatureResponseSchema(schema.ResponseSchema):
    """QueryUSMSSignature - 调用接口QueryUSMSSignature查询短信签名申请状态"""

    fields = {
        "Data": models.OutSignatureSchema(),
        "Message": fields.Str(required=True, load_from="Message"),
    }


"""
API: QueryUSMSTemplate

调用接口QueryUSMSTemplate查询短信模板申请状态
"""


class QueryUSMSTemplateRequestSchema(schema.RequestSchema):
    """QueryUSMSTemplate - 调用接口QueryUSMSTemplate查询短信模板申请状态"""

    fields = {
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "TemplateId": fields.Str(required=True, dump_to="TemplateId"),
    }


class QueryUSMSTemplateResponseSchema(schema.ResponseSchema):
    """QueryUSMSTemplate - 调用接口QueryUSMSTemplate查询短信模板申请状态"""

    fields = {
        "Data": models.OutTemplateSchema(),
        "Message": fields.Str(required=False, load_from="Message"),
    }


"""
API: SendBatchUSMSMessage

调用SendBatchUSMSMessage接口批量发送短信
"""


class SendBatchUSMSMessageRequestSchema(schema.RequestSchema):
    """SendBatchUSMSMessage - 调用SendBatchUSMSMessage接口批量发送短信"""

    fields = {
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "TaskContent": fields.Str(required=True, dump_to="TaskContent"),
    }


class SendBatchUSMSMessageResponseSchema(schema.ResponseSchema):
    """SendBatchUSMSMessage - 调用SendBatchUSMSMessage接口批量发送短信"""

    fields = {
        "FailContent": fields.List(
            models.BatchInfoSchema(), required=False, load_from="FailContent"
        ),
        "Message": fields.Str(required=True, load_from="Message"),
        "ReqUuid": fields.Str(required=False, load_from="ReqUuid"),
        "SessionNo": fields.Str(required=False, load_from="SessionNo"),
        "SuccessCount": fields.Int(required=False, load_from="SuccessCount"),
    }


"""
API: SendUSMSMessage

调用接口SendUSMSMessage发送短信
"""


class SendUSMSMessageRequestSchema(schema.RequestSchema):
    """SendUSMSMessage - 调用接口SendUSMSMessage发送短信"""

    fields = {
        "ExtendCode": fields.Str(required=False, dump_to="ExtendCode"),
        "PhoneNumbers": fields.List(fields.Str()),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(
            required=False, dump_to="Region"
        ),  # Deprecated, will be removed at 1.0
        "SigContent": fields.Str(required=True, dump_to="SigContent"),
        "TemplateId": fields.Str(required=True, dump_to="TemplateId"),
        "TemplateParams": fields.List(fields.Str()),
        "UserId": fields.Str(required=False, dump_to="UserId"),
        "Zone": fields.Str(
            required=False, dump_to="Zone"
        ),  # Deprecated, will be removed at 1.0
    }


class SendUSMSMessageResponseSchema(schema.ResponseSchema):
    """SendUSMSMessage - 调用接口SendUSMSMessage发送短信"""

    fields = {
        "Message": fields.Str(required=True, load_from="Message"),
        "SessionNo": fields.Str(required=False, load_from="SessionNo"),
        "UserId": fields.Str(required=False, load_from="UserId"),
    }


"""
API: UpdateUSMSSignature

调用接口UpdateUSMSSignature修改未通过审核的短信签名，并重新提交审核
"""


class UpdateUSMSSignatureRequestSchema(schema.RequestSchema):
    """UpdateUSMSSignature - 调用接口UpdateUSMSSignature修改未通过审核的短信签名，并重新提交审核"""

    fields = {
        "CertificateType": fields.Int(
            required=False, dump_to="CertificateType"
        ),
        "Document": fields.Str(required=False, dump_to="Document"),
        "File": fields.Str(required=False, dump_to="File"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "ProxyDoc": fields.Str(required=False, dump_to="ProxyDoc"),
        "ProxyFile": fields.Str(required=False, dump_to="ProxyFile"),
        "SigContent": fields.Str(required=True, dump_to="SigContent"),
        "SigId": fields.Str(required=True, dump_to="SigId"),
        "SigPurpose": fields.Int(required=True, dump_to="SigPurpose"),
        "SigType": fields.Int(required=True, dump_to="SigType"),
    }


class UpdateUSMSSignatureResponseSchema(schema.ResponseSchema):
    """UpdateUSMSSignature - 调用接口UpdateUSMSSignature修改未通过审核的短信签名，并重新提交审核"""

    fields = {
        "Message": fields.Str(required=True, load_from="Message"),
    }


"""
API: UpdateUSMSTemplate

调用接口UpdateUSMSTemplate修改未通过审核的短信模板，并重新提交审核
"""


class UpdateUSMSTemplateRequestSchema(schema.RequestSchema):
    """UpdateUSMSTemplate - 调用接口UpdateUSMSTemplate修改未通过审核的短信模板，并重新提交审核"""

    fields = {
        "Instruction": fields.Str(required=False, dump_to="Instruction"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(
            required=False, dump_to="Region"
        ),  # Deprecated, will be removed at 1.0
        "Remark": fields.Str(required=False, dump_to="Remark"),
        "Template": fields.Str(required=True, dump_to="Template"),
        "TemplateId": fields.Str(required=True, dump_to="TemplateId"),
        "TemplateName": fields.Str(required=False, dump_to="TemplateName"),
        "UnsubscribeInfo": fields.Str(
            required=False, dump_to="UnsubscribeInfo"
        ),  # Deprecated, will be removed at 1.0
        "Zone": fields.Str(
            required=False, dump_to="Zone"
        ),  # Deprecated, will be removed at 1.0
    }


class UpdateUSMSTemplateResponseSchema(schema.ResponseSchema):
    """UpdateUSMSTemplate - 调用接口UpdateUSMSTemplate修改未通过审核的短信模板，并重新提交审核"""

    fields = {
        "Message": fields.Str(required=True, load_from="Message"),
    }



""" Code is generated by ucloud-model, DO NOT EDIT IT. """

import typing


from ucloud.core.client import Client
from ucloud.services.utsdb.schemas import apis


class UTSDBClient(Client):
    def __init__(
        self, config: dict, transport=None, middleware=None, logger=None
    ):
        super(UTSDBClient, self).__init__(config, transport, middleware, logger)

    def check_uinfluxdb_allowance(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """CheckUInfluxdbAllowance - 检查UInfluxdb剩余资源

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **Count** (int) - (Required) 创建实例的数量，[1-10]
        - **CpuLimit** (int) - (Required) 核数 单位：个，范围［2C8G, 4C16G, 8C32G, 16C64G, 32C128G］
        - **MemoryLimit** (int) - (Required) 内存限制 单位：G 范围 [2C8G, 4C16G, 8C32G, 16C64G, 32C128G］
        - **Zone** (str) - (Required) 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_

        **Response**

        - **Count** (int) - 可创建的数量

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.CheckUInfluxdbAllowanceRequestSchema().dumps(d)

        resp = self.invoke("CheckUInfluxdbAllowance", d, **kwargs)
        return apis.CheckUInfluxdbAllowanceResponseSchema().loads(resp)

    def create_uinfluxdb_database(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """CreateUInfluxdbDatabase - 创建Influxdb数据库

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **DatabaseName** (str) - (Required) Influxdb创建的数据库的名称
        - **UInfluxdbId** (str) - (Required) 实例ID
        - **Zone** (str) - (Required) 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **AccoutName** (str) - Influxdb数据库账号
        - **Description** (str) - Influxdb数据库的描述
        - **RetentionPolicy** (str) - 数据保留策略，以天为单位，比如（1d，2d，3d等，inf为永久保留策略，默认为inf）

        **Response**


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.CreateUInfluxdbDatabaseRequestSchema().dumps(d)

        # build options
        kwargs["max_retries"] = 0  # ignore retry when api is not idempotent

        resp = self.invoke("CreateUInfluxdbDatabase", d, **kwargs)
        return apis.CreateUInfluxdbDatabaseResponseSchema().loads(resp)

    def create_uinfluxdb_database_rp(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """CreateUInfluxdbDatabaseRP - 给指定的database创建一个保留策略，最多可以创建10个RP

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **DatabaseName** (str) - (Required) 要创建RP的数据库
        - **RetentionPolicy** (str) - (Required) 数据保留策略，以天为单位，比如（1d，2d，3d等，inf为永久保留策略，默认为inf）
        - **RetentionPolicyName** (str) - (Required) 保留策略名
        - **UInfluxdbId** (str) - (Required) 实例ID
        - **Zone** (str) - (Required) 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_

        **Response**

        - **Message** (str) - 如果执行失败, 失败的错误消息

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.CreateUInfluxdbDatabaseRPRequestSchema().dumps(d)

        # build options
        kwargs["max_retries"] = 0  # ignore retry when api is not idempotent

        resp = self.invoke("CreateUInfluxdbDatabaseRP", d, **kwargs)
        return apis.CreateUInfluxdbDatabaseRPResponseSchema().loads(resp)

    def create_uinfluxdb_instance(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """CreateUInfluxdbInstance - 创建UInfluxdb实例

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **AccountName** (str) - (Required) 默认账户
        - **ChargeType** (str) - (Required) 付费类型，后付费阶段固定为：后付费（PostPaid）
        - **CpuLimit** (int) - (Required) 核数 单位：个，范围［2C8G, 4C16G, 8C32G, 16C64G, 32C128G］
        - **DatabaseName** (str) - (Required) 数据库名称
        - **MemoryLimit** (int) - (Required) 内存限制 单位：G 范围 [2C8G, 4C16G, 8C32G, 16C64G, 32C128G］
        - **Name** (str) - (Required) 实例名称，长度(6<=size<=63)
        - **Password** (str) - (Required) 默认账户的密码，需要 base64 编码
        - **Quantity** (int) - (Required) 购买时长，默认值1
        - **SubnetId** (str) - (Required) 子网 id
        - **VPCId** (str) - (Required) VPC id
        - **Zone** (str) - (Required) 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **CouponId** (str) - 使用的代金券id
        - **Tag** (str) - 业务组名称

        **Response**

        - **UInfluxdbId** (str) - 返回的实例id

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.CreateUInfluxdbInstanceRequestSchema().dumps(d)

        # build options
        kwargs["max_retries"] = 0  # ignore retry when api is not idempotent

        resp = self.invoke("CreateUInfluxdbInstance", d, **kwargs)
        return apis.CreateUInfluxdbInstanceResponseSchema().loads(resp)

    def delete_uinfluxdb_database(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """DeleteUInfluxdbDatabase - 删除Influxdb实例的数据库

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **DatabaseName** (str) - (Required) 数据库名称
        - **UInfluxdbId** (str) - (Required) 实例id
        - **Zone** (str) - (Required) 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_

        **Response**


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.DeleteUInfluxdbDatabaseRequestSchema().dumps(d)

        resp = self.invoke("DeleteUInfluxdbDatabase", d, **kwargs)
        return apis.DeleteUInfluxdbDatabaseResponseSchema().loads(resp)

    def delete_uinfluxdb_database_rp(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """DeleteUInfluxdbDatabaseRP - 删除指定数据库下面的一个数据保留策略

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **DatabaseName** (str) - (Required) 要删除的RP所在数据库
        - **RetentionPolicyName** (str) - (Required) 要删除的保留策略
        - **UInfluxdbId** (str) - (Required) 实例ID
        - **Zone** (str) - (Required) 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_

        **Response**

        - **Message** (str) - 如果执行失败, 失败的错误消息

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.DeleteUInfluxdbDatabaseRPRequestSchema().dumps(d)

        resp = self.invoke("DeleteUInfluxdbDatabaseRP", d, **kwargs)
        return apis.DeleteUInfluxdbDatabaseRPResponseSchema().loads(resp)

    def delete_uinfluxdb_instance(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """DeleteUInfluxdbInstance - 删除UInfluxdb实例

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **UInfluxdbId** (str) - (Required) UInfluxdb 实例id
        - **Zone** (str) - (Required) 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_

        **Response**


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.DeleteUInfluxdbInstanceRequestSchema().dumps(d)

        resp = self.invoke("DeleteUInfluxdbInstance", d, **kwargs)
        return apis.DeleteUInfluxdbInstanceResponseSchema().loads(resp)

    def describe_uinfluxdb_database(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """DescribeUInfluxdbDatabase - 描述UInfluxdb数据库

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **UInfluxdbId** (str) - (Required)
        - **Zone** (str) - (Required) 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **DatabaseName** (str) -
        - **Limit** (int) -
        - **Offset** (int) -

        **Response**

        - **DatabaseInfo** (list) - 见 **DatabaseInfo** 模型定义

        **Response Model**

        **AccountInfo**
        - **Account** (str) - 账户名
        - **Password** (str) - 密码
        - **Privilege** (str) - 权限


        **DatabaseInfo**
        - **AccountInfo** (list) - 见 **AccountInfo** 模型定义
        - **DatabaseName** (str) - 数据库名
        - **Description** (str) - 数据库描述
        - **RetentionPolicy** (str) - 保留策略
        - **State** (str) - 数据库状态


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.DescribeUInfluxdbDatabaseRequestSchema().dumps(d)

        resp = self.invoke("DescribeUInfluxdbDatabase", d, **kwargs)
        return apis.DescribeUInfluxdbDatabaseResponseSchema().loads(resp)

    def describe_uinfluxdb_database_rp(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """DescribeUInfluxdbDatabaseRP - 获取指定数据库下面的所有保留策略

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **DatabaseName** (str) - (Required) 数据库名称
        - **UInfluxdbId** (str) - (Required) 实例ID
        - **Zone** (str) - (Required) 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_

        **Response**

        - **DataSet** (list) - 见 **RpData** 模型定义
        - **Message** (str) - 如果执行失败, 失败的错误消息

        **Response Model**

        **RpData**
        - **Policy** (str) - 保留策略
        - **RetentionPolicyName** (str) - 保留策略名


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.DescribeUInfluxdbDatabaseRPRequestSchema().dumps(d)

        resp = self.invoke("DescribeUInfluxdbDatabaseRP", d, **kwargs)
        return apis.DescribeUInfluxdbDatabaseRPResponseSchema().loads(resp)

    def describe_uinfluxdb_instance(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """DescribeUInfluxdbInstance - 拉取UInfluxdb实例列表

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **Zone** (str) - (Required) 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **Limit** (int) - 分页显示数量，列表操作则指定
        - **Offset** (int) - 分页显示起始偏移位置，列表操作则指定
        - **UInfluxdbId** (str) - 指定id的话，会拉取该实例信息，否则拉取该帐号所有信息

        **Response**

        - **DataSet** (list) - 见 **UInfluxdbDataSet** 模型定义

        **Response Model**

        **UInfluxdbDataSet**
        - **AccountName** (str) - 账户名
        - **CPULimit** (int) - 实例核数
        - **ChargeType** (str) - 付费类型，可选值如下: Year: 按年付费 Month: 按月付费 Dynamic: 按需付费(单位: 小时) Trial: 免费试用
        - **CreateTime** (int) - 创建时间
        - **ExpiredTime** (int) - 修改时间
        - **MemoryLimit** (int) - 实例内存
        - **Name** (str) - 实例名称
        - **Port** (int) - 实例端口
        - **State** (str) - 实例状态
        - **SubnetId** (str) - 子网ID
        - **Tag** (str) - 业务组信息
        - **UInfluxdbId** (str) - 实例id
        - **UsedSize** (int) - 硬盘使用量
        - **VPCId** (str) - VPC的ID
        - **VirtualIP** (str) - 实例ip
        - **Zone** (str) - UInfluxdb实例所在可用区


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.DescribeUInfluxdbInstanceRequestSchema().dumps(d)

        resp = self.invoke("DescribeUInfluxdbInstance", d, **kwargs)
        return apis.DescribeUInfluxdbInstanceResponseSchema().loads(resp)

    def describe_uinfluxdb_price(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """DescribeUInfluxdbPrice - 获取UInfluxdb价格

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **CpuLimit** (int) - (Required) 核数 单位：个，规格［2C8G, 4C16G, 8C32G, 16C64G, 32C128G］
        - **Zone** (str) - (Required) 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **ChargeType** (str) - 付费类型，后付费。填：PostPaid (后付费)
        - **MemoryLimit** (int) - 内存限制 单位：G 规格 [2C8G, 4C16G, 8C32G, 16C64G, 32C128G］
        - **Quantity** (int) - 付费周期数量

        **Response**

        - **OriginalPrice** (float) - 原价
        - **Price** (float) - 价格

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.DescribeUInfluxdbPriceRequestSchema().dumps(d)

        resp = self.invoke("DescribeUInfluxdbPrice", d, **kwargs)
        return apis.DescribeUInfluxdbPriceResponseSchema().loads(resp)

    def describe_uinfluxdb_upgrade_price(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """DescribeUInfluxdbUpgradePrice - 获取UIfluxdb升降级价格

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **CpuLimit** (int) - (Required) 核数
        - **MemoryLimit** (int) - (Required) 容量，单位GB
        - **UInfluxdbId** (str) - (Required) UInfluxdb 实例id
        - **Zone** (str) - (Required) 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_

        **Response**

        - **OriginalPrice** (float) - 原价
        - **TotalPrice** (float) - 升降级价格

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.DescribeUInfluxdbUpgradePriceRequestSchema().dumps(d)

        resp = self.invoke("DescribeUInfluxdbUpgradePrice", d, **kwargs)
        return apis.DescribeUInfluxdbUpgradePriceResponseSchema().loads(resp)

    def modify_uinfluxdb_database_policy(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """ModifyUInfluxdbDatabasePolicy - 更改UInfluxdb实例数据库数据保留策略

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **DatabaseName** (str) - (Required) 数据库名
        - **RetentionPolicy** (str) - (Required) 数据库数据保留策略。自定义格式如：10d（即10天），2w（即两周），
        - **UInfluxdbId** (str) - (Required) Influxdb实例id
        - **Zone** (str) - (Required) 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_

        **Response**


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.ModifyUInfluxdbDatabasePolicyRequestSchema().dumps(d)

        resp = self.invoke("ModifyUInfluxdbDatabasePolicy", d, **kwargs)
        return apis.ModifyUInfluxdbDatabasePolicyResponseSchema().loads(resp)

    def reboot_uinfluxdb_instance(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """RebootUInfluxdbInstance - 重启UInfluxdb实例

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **UInfluxdbId** (str) - (Required) UInfluxdb实例id
        - **Zone** (str) - (Required) 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_

        **Response**


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.RebootUInfluxdbInstanceRequestSchema().dumps(d)

        resp = self.invoke("RebootUInfluxdbInstance", d, **kwargs)
        return apis.RebootUInfluxdbInstanceResponseSchema().loads(resp)

    def reset_uinfluxdb_instance_name(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """ResetUInfluxdbInstanceName - 更改UIfluxdb实例名称

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **NewName** (str) - (Required) 实例的新名字, 长度要求为6~63位
        - **UInfluxdbId** (str) - (Required) UInfluxdb实例id
        - **Zone** (str) - (Required) 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_

        **Response**


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.ResetUInfluxdbInstanceNameRequestSchema().dumps(d)

        resp = self.invoke("ResetUInfluxdbInstanceName", d, **kwargs)
        return apis.ResetUInfluxdbInstanceNameResponseSchema().loads(resp)

    def start_uinfluxdb_instance(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """StartUInfluxdbInstance - 启动UInfluxdb实例

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **UInfluxdbId** (str) - (Required) UInfluxdb实例id
        - **Zone** (str) - (Required) 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_

        **Response**


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.StartUInfluxdbInstanceRequestSchema().dumps(d)

        resp = self.invoke("StartUInfluxdbInstance", d, **kwargs)
        return apis.StartUInfluxdbInstanceResponseSchema().loads(resp)

    def stop_uinfluxdb_instance(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """StopUInfluxdbInstance - 关闭UInfluxdb实例

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **UInfluxdbId** (str) - (Required) UInfluxdb实例id
        - **Zone** (str) - (Required) 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_

        **Response**


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.StopUInfluxdbInstanceRequestSchema().dumps(d)

        resp = self.invoke("StopUInfluxdbInstance", d, **kwargs)
        return apis.StopUInfluxdbInstanceResponseSchema().loads(resp)

    def upgrade_uinfluxdb_instance(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """UpgradeUInfluxdbInstance - UInfluxdb实例配置升降级

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **CpuLimit** (int) - (Required) UInfluxdb 实例 新的核数，单位个
        - **MemoryLimit** (int) - (Required) UInfluxdb 实例 新的内存
        - **UInfluxdbId** (str) - (Required) 实例ID
        - **Zone** (str) - (Required) 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_

        **Response**


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.UpgradeUInfluxdbInstanceRequestSchema().dumps(d)

        resp = self.invoke("UpgradeUInfluxdbInstance", d, **kwargs)
        return apis.UpgradeUInfluxdbInstanceResponseSchema().loads(resp)



""" Code is generated by ucloud-model, DO NOT EDIT IT. """

from ucloud.core.typesystem import schema, fields


class SlaveInfoSchema(schema.ResponseSchema):
    """SlaveInfo - UDDB只读实例信息"""

    fields = {
        "DataNodeId": fields.Str(required=False, load_from="DataNodeId"),
        "Id": fields.Str(required=False, load_from="Id"),
        "State": fields.Str(required=False, load_from="State"),
    }


class DataNodeInfoSchema(schema.ResponseSchema):
    """DataNodeInfo - UDDB存储节点和下挂的只读实例信息"""

    fields = {
        "CreateTime": fields.Str(required=False, load_from="CreateTime"),
        "DiskSpace": fields.Str(required=False, load_from="DiskSpace"),
        "Id": fields.Str(required=False, load_from="Id"),
        "LastTransTaskId": fields.Str(
            required=False, load_from="LastTransTaskId"
        ),
        "Memory": fields.Str(required=False, load_from="Memory"),
        "SlaveCount": fields.Str(required=False, load_from="SlaveCount"),
        "SlaveInfos": fields.List(SlaveInfoSchema()),
        "State": fields.Str(required=False, load_from="State"),
    }


class DataSetUDDBSchema(schema.ResponseSchema):
    """DataSetUDDB - UDDB信息的DataSet"""

    fields = {
        "AdminUser": fields.Str(required=False, load_from="AdminUser"),
        "ChargeType": fields.Str(required=False, load_from="ChargeType"),
        "CreateTime": fields.Str(required=False, load_from="CreateTime"),
        "DBTypeId": fields.Str(required=False, load_from="DBTypeId"),
        "DataNodeCount": fields.Str(required=False, load_from="DataNodeCount"),
        "DataNodeDiskSpace": fields.Str(
            required=False, load_from="DataNodeDiskSpace"
        ),
        "DataNodeList": fields.List(DataNodeInfoSchema()),
        "DataNodeMemory": fields.Str(
            required=False, load_from="DataNodeMemory"
        ),
        "DataNodeSlaveCount": fields.Str(
            required=False, load_from="DataNodeSlaveCount"
        ),
        "ExpiredTime": fields.Str(required=False, load_from="ExpiredTime"),
        "InstanceMode": fields.Str(required=False, load_from="InstanceMode"),
        "InstanceType": fields.Str(required=False, load_from="InstanceType"),
        "Name": fields.Str(required=False, load_from="Name"),
        "Port": fields.Str(required=False, load_from="Port"),
        "RefQps": fields.Int(required=False, load_from="RefQps"),
        "RouterNodeNum": fields.Int(required=False, load_from="RouterNodeNum"),
        "RouterVersion": fields.Str(required=False, load_from="RouterVersion"),
        "State": fields.Str(required=False, load_from="State"),
        "UDDBId": fields.Str(required=False, load_from="UDDBId"),
        "VirtualIP": fields.Str(required=False, load_from="VirtualIP"),
        "Zone": fields.Str(required=False, load_from="Zone"),
    }


class PriceDetailInfoSchema(schema.ResponseSchema):
    """PriceDetailInfo - UDDB实例计费详情"""

    fields = {
        "DataNodePrice": fields.Float(
            required=False, load_from="DataNodePrice"
        ),
        "DataNodeSlavePrice": fields.Float(
            required=False, load_from="DataNodeSlavePrice"
        ),
        "MiddlewarePrice": fields.Float(
            required=False, load_from="MiddlewarePrice"
        ),
    }


class PriceInfoSchema(schema.ResponseSchema):
    """PriceInfo - UDDB实例计费详情"""

    fields = {
        "DataNodePrice": fields.Float(
            required=False, load_from="DataNodePrice"
        ),
        "DataNodeSlavePrice": fields.Float(
            required=False, load_from="DataNodeSlavePrice"
        ),
        "MiddlewarePrice": fields.Float(
            required=False, load_from="MiddlewarePrice"
        ),
    }



""" Code is generated by ucloud-model, DO NOT EDIT IT. """

from ucloud.core.typesystem import schema, fields


class IPSetSchema(schema.ResponseSchema):
    """IPSet - 节点的IP信息"""

    fields = {
        "Bandwidth": fields.Int(required=False, load_from="Bandwidth"),
        "Default": fields.Str(required=False, load_from="Default"),
        "IP": fields.Str(required=False, load_from="IP"),
        "IPId": fields.Str(required=False, load_from="IPId"),
        "Type": fields.Str(required=False, load_from="Type"),
    }


class DiskSetSchema(schema.ResponseSchema):
    """DiskSet - 节点磁盘信息"""

    fields = {
        "BackupType": fields.Str(required=False, load_from="BackupType"),
        "DiskId": fields.Str(required=False, load_from="DiskId"),
        "DiskType": fields.Str(required=False, load_from="DiskType"),
        "Drive": fields.Str(required=False, load_from="Drive"),
        "Encrypted": fields.Str(required=False, load_from="Encrypted"),
        "IOPS": fields.Int(required=False, load_from="IOPS"),
        "IsBoot": fields.Str(required=False, load_from="IsBoot"),
        "Name": fields.Str(required=False, load_from="Name"),
        "Size": fields.Int(required=False, load_from="Size"),
        "Type": fields.Str(required=False, load_from="Type"),
    }


class UhostInfoSchema(schema.ResponseSchema):
    """UhostInfo - 机器信息"""

    fields = {
        "CPU": fields.Int(required=True, load_from="CPU"),
        "CreateTime": fields.Int(required=True, load_from="CreateTime"),
        "DiskSet": fields.List(DiskSetSchema()),
        "ExpireTime": fields.Int(required=True, load_from="ExpireTime"),
        "IPSet": fields.List(IPSetSchema()),
        "Memory": fields.Int(required=True, load_from="Memory"),
        "Name": fields.Str(required=True, load_from="Name"),
        "NodeId": fields.Str(required=True, load_from="NodeId"),
        "NodeType": fields.Str(required=True, load_from="NodeType"),
        "OsName": fields.Str(required=True, load_from="OsName"),
        "State": fields.Str(required=True, load_from="State"),
        "Zone": fields.Str(required=True, load_from="Zone"),
    }


class KubeProxySchema(schema.ResponseSchema):
    """KubeProxy - KubeProxy信息"""

    fields = {
        "Mode": fields.Str(required=False, load_from="Mode"),
    }


class ImageInfoSchema(schema.ResponseSchema):
    """ImageInfo - UK8S 可用镜像信息"""

    fields = {
        "ImageId": fields.Str(required=True, load_from="ImageId"),
        "ImageName": fields.Str(required=True, load_from="ImageName"),
        "NotSupportGPU": fields.Bool(required=True, load_from="NotSupportGPU"),
        "ZoneId": fields.Int(required=True, load_from="ZoneId"),
    }


class K8SNodeConditionSchema(schema.ResponseSchema):
    """K8SNodeCondition - Kubernetes Node Condition"""

    fields = {
        "LastProbeTime": fields.Str(required=False, load_from="LastProbeTime"),
        "LastTransitionTime": fields.Str(
            required=False, load_from="LastTransitionTime"
        ),
        "Message": fields.Str(required=False, load_from="Message"),
        "Reason": fields.Str(required=False, load_from="Reason"),
        "Status": fields.Str(required=False, load_from="Status"),
        "Type": fields.Str(required=False, load_from="Type"),
    }


class UHostIPSetSchema(schema.ResponseSchema):
    """UHostIPSet - 云主机IP信息"""

    fields = {
        "Bandwidth": fields.Int(required=False, load_from="Bandwidth"),
        "Default": fields.Str(
            required=False, load_from="Default"
        ),  # Deprecated, will be removed at 1.0
        "IP": fields.Str(required=False, load_from="IP"),
        "IPId": fields.Str(required=False, load_from="IPId"),
        "Mac": fields.Str(required=False, load_from="Mac"),
        "SubnetId": fields.Str(required=False, load_from="SubnetId"),
        "Type": fields.Str(required=False, load_from="Type"),
        "VPCId": fields.Str(required=False, load_from="VPCId"),
    }


class NodeInfoV2Schema(schema.ResponseSchema):
    """NodeInfoV2 - UK8S 节点信息"""

    fields = {
        "AsgId": fields.Str(required=True, load_from="AsgId"),
        "CPU": fields.Int(required=True, load_from="CPU"),
        "CreateTime": fields.Int(required=True, load_from="CreateTime"),
        "ExpireTime": fields.Int(required=True, load_from="ExpireTime"),
        "GPU": fields.Int(required=False, load_from="GPU"),
        "IPSet": fields.List(UHostIPSetSchema()),
        "InstanceId": fields.Str(required=True, load_from="InstanceId"),
        "InstanceName": fields.Str(required=True, load_from="InstanceName"),
        "InstanceType": fields.Str(required=True, load_from="InstanceType"),
        "KubeProxy": KubeProxySchema(),
        "MachineType": fields.Str(required=True, load_from="MachineType"),
        "Memory": fields.Int(required=True, load_from="Memory"),
        "NodeId": fields.Str(required=True, load_from="NodeId"),
        "NodeLogInfo": fields.Str(required=True, load_from="NodeLogInfo"),
        "NodeRole": fields.Str(required=True, load_from="NodeRole"),
        "NodeStatus": fields.Str(required=True, load_from="NodeStatus"),
        "OsName": fields.Str(required=True, load_from="OsName"),
        "OsType": fields.Str(required=True, load_from="OsType"),
        "Unschedulable": fields.Bool(required=True, load_from="Unschedulable"),
        "Zone": fields.Str(required=True, load_from="Zone"),
    }


class ClusterSetSchema(schema.ResponseSchema):
    """ClusterSet - 集群信息"""

    fields = {
        "ApiServer": fields.Str(required=True, load_from="ApiServer"),
        "ClusterId": fields.Str(required=True, load_from="ClusterId"),
        "ClusterLogInfo": fields.Str(
            required=False, load_from="ClusterLogInfo"
        ),
        "ClusterName": fields.Str(required=True, load_from="ClusterName"),
        "CreateTime": fields.Int(required=False, load_from="CreateTime"),
        "ExternalApiServer": fields.Str(
            required=False, load_from="ExternalApiServer"
        ),
        "K8sVersion": fields.Str(required=True, load_from="K8sVersion"),
        "MasterCount": fields.Int(required=True, load_from="MasterCount"),
        "NodeCount": fields.Int(required=False, load_from="NodeCount"),
        "PodCIDR": fields.Str(required=True, load_from="PodCIDR"),
        "ServiceCIDR": fields.Str(required=True, load_from="ServiceCIDR"),
        "Status": fields.Str(required=False, load_from="Status"),
        "SubnetId": fields.Str(required=True, load_from="SubnetId"),
        "VPCId": fields.Str(required=True, load_from="VPCId"),
    }


class NodeGroupSetSchema(schema.ResponseSchema):
    """NodeGroupSet - 节点池配置"""

    fields = {
        "BootDiskType": fields.Str(required=False, load_from="BootDiskType"),
        "CPU": fields.Int(required=False, load_from="CPU"),
        "ChargeType": fields.Str(required=False, load_from="ChargeType"),
        "DataDiskSize": fields.Int(required=False, load_from="DataDiskSize"),
        "DataDiskType": fields.Str(required=False, load_from="DataDiskType"),
        "GPU": fields.Int(required=False, load_from="GPU"),
        "GpuType": fields.Str(required=False, load_from="GpuType"),
        "ImageId": fields.Str(required=False, load_from="ImageId"),
        "MachineType": fields.Str(required=False, load_from="MachineType"),
        "Mem": fields.Int(required=False, load_from="Mem"),
        "MinimalCpuPlatform": fields.Str(
            required=False, load_from="MinimalCpuPlatform"
        ),
        "NodeGroupId": fields.Str(required=False, load_from="NodeGroupId"),
        "NodeGroupName": fields.Str(required=False, load_from="NodeGroupName"),
        "NodeList": fields.List(fields.Str()),
        "Tag": fields.Str(required=False, load_from="Tag"),
    }



import logging
from ucloud.core.typesystem import abstract
from ucloud.core.exc import ValidationException
from ucloud.core.utils import compat

logger = logging.getLogger(__name__)


class Schema(abstract.Schema):
    fields = {}  # noqa: F811

    def dumps(self, d: dict, name=None, **kwargs) -> dict:
        result = {}
        errors = []

        for k, field in self.fields.items():
            v = d.get(k)

            # resolve value is empty
            if v is None:
                if field.required:
                    errors.append(
                        ValidationException(
                            "the field {k} is required".format(k=k)
                        )
                    )
                    continue

                if field.default is None:
                    continue

                if isinstance(field.default, compat.Callable):
                    v = field.default()
                else:
                    v = field.default

            try:
                serialized = field.dumps(v, name=k)
            except ValidationException as e:
                errors.extend(e.errors)
                continue

            result[field.dump_to or k] = serialized

        if len(errors) > 0:
            raise ValidationException(errors)

        return result

    def loads(self, d: dict, name=None, **kwargs) -> dict:
        result = {}
        errors = []

        if not self.case_sensitive:
            d = {k.lower(): v for k, v in d.items()}

        for k, field in self.fields.items():
            load_key = field.load_from or k
            v = d.get(load_key if self.case_sensitive else load_key.lower())
            if v is None:
                if field.default is None:
                    continue

                if isinstance(field.default, compat.Callable):
                    v = field.default()
                else:
                    v = field.default

            try:
                serialized = field.loads(v, name=k)
            except ValidationException as e:
                errors.extend(e.errors)
                continue

            result[k] = serialized

        if len(errors) > 0:
            raise ValidationException(errors)

        return result


class RequestSchema(Schema):
    fields = {}  # noqa: F811

    def dumps(self, d: dict, name=None, **kwargs) -> dict:
        if not isinstance(d, dict):
            raise ValidationException(
                "invalid field {}, expect dict, got {}".format(name, type(d))
            )

        result = super(RequestSchema, self).dumps(d, name=name, **kwargs)
        return result


class ResponseSchema(Schema):
    pass



""" Code is generated by ucloud-model, DO NOT EDIT IT. """

import typing


from ucloud.core.client import Client
from ucloud.services.unvs.schemas import apis


class UNVSClient(Client):
    def __init__(
        self, config: dict, transport=None, middleware=None, logger=None
    ):
        super(UNVSClient, self).__init__(config, transport, middleware, logger)

    def get_mobile(self, req: typing.Optional[dict] = None, **kwargs) -> dict:
        """GetMobile - 一键登录

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **BusinessId** (str) - (Required) 业务ID
        - **Token** (str) - (Required) token
        - **Zone** (str) - 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_

        **Response**

        - **Data** (dict) - 见 **PhoneInfo** 模型定义
        - **Message** (str) - 发生错误时表示错误字符串
        - **ReqUuid** (str) - 本次请求Uuid

        **Response Model**

        **PhoneInfo**
        - **Phone** (str) - 返回的电话号码


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.GetMobileRequestSchema().dumps(d)

        resp = self.invoke("GetMobile", d, **kwargs)
        return apis.GetMobileResponseSchema().loads(resp)

    def verify_mobile(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """VerifyMobile - 号码检测

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **BusinessId** (str) - (Required) 业务ID
        - **Phone** (str) - (Required) 需要检测的手机号
        - **Token** (str) - (Required) token
        - **Zone** (str) - 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_

        **Response**

        - **Data** (dict) - 见 **VerifyInfo** 模型定义
        - **Message** (str) - 发生错误时表示错误字符串
        - **ReqUuid** (str) - 本次请求Uuid

        **Response Model**

        **VerifyInfo**
        - **VerifyResult** (str) - 检测结果：PASS：一致，REJECT：不一致


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.VerifyMobileRequestSchema().dumps(d)

        resp = self.invoke("VerifyMobile", d, **kwargs)
        return apis.VerifyMobileResponseSchema().loads(resp)
